@@ -233,9 +233,8 @@ class HtmlLogger(StandardLogger):
 
     def init(self):
         self.starttime = time.time()
-        self.fd.write('<!DOCTYPE html PUBLIC "-//W3C//DTD html 4.0//'+
-              linkcheck.LANG+
-	      '">\n<html><head><title>'+Config.App+"</title>\n"
+        self.fd.write('<!DOCTYPE html PUBLIC "-//W3C//DTD html 4.0//en">\n'+
+	      '<html><head><title>'+Config.App+"</title>\n"
 	      '<style type="text/css">\n<!--\n'
               "h2 { font-family: Verdana,sans-serif; font-size: 22pt; \n"
 	      "     font-style: bold; font-weight: bold }\n"
@@ -360,7 +359,7 @@ class ColoredLogger(StandardLogger):
     """ANSI colorized output"""
 
     def __init__(self, **args):
-        esc="\033[%s"
+        esc="\x1b[%sm"
         apply(StandardLogger.__init__, (self,), args)
         self.colorparent = esc % args['colorparent']
         self.colorurl = esc % args['colorurl']
