@@ -19,33 +19,20 @@ class error(Exception):
     pass
 
 # i18n suppport
-LANG="EN" # default language (used for HTML output)
-import _linkchecker_configdata
+import os, _linkchecker_configdata
 try:
-    import fintl,os,string
-    gettext = fintl.gettext
+    import gettext
     domain = 'linkcheck'
     localedir = os.path.join(_linkchecker_configdata.install_data, 'locale')
-    fintl.bindtextdomain(domain, localedir)
-    fintl.textdomain(domain)
-    languages = []
-    for envvar in ('LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG'):
-        if os.environ.has_key(envvar):
-            languages = string.split(os.environ[envvar], ':')
-            break
-    if languages:
-        LANG=string.upper(languages[0])
-
-except ImportError:
-    def gettext(msg):
-        return msg
-# set _ as an alias for gettext
-_ = gettext
+    t = gettext.translation(domain, localedir)
+    _ = t.gettext
+except IOError:
+    _ = lambda s: s
 
 #import timeoutsocket
 #timeoutsocket.setDefaultSocketTimeout(20)
 
-import Config,UrlData,sys,lc_cgi
+import Config, UrlData, sys, lc_cgi
 from debuglevels import *
 debug = Config.debug
 
